#
# spec file for package libFS
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libFS
%define lname	libFS6
Version:        1.0.9
Release:        1.4
Summary:        X Font Service client library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            http://xorg.freedesktop.org/

#Git-Clone:	git://anongit.freedesktop.org/xorg/lib/libFS
#Git-Web:	http://cgit.freedesktop.org/xorg/lib/libFS/
Source:         http://xorg.freedesktop.org/releases/individual/lib/%{name}-%{version}.tar.xz
Source2:        baselibs.conf

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#git#BuildRequires:	autoconf >= 2.60, automake, libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xtrans)

%description
This library is used by clients of X Font Servers (xfs), such as
xfsinfo, xfslsfonts, and the X servers themselves.

%package -n %lname
Summary:        X Font Service client library
Group:          System/Libraries

%description -n %lname
This library is used by clients of X Font Servers (xfs), such as
xfsinfo, xfslsfonts, and the X servers themselves.

%package devel
Summary:        Development files for the X Font Service client library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
This library is used by clients of X Font Servers (xfs), such as
xfsinfo, xfslsfonts, and the X servers themselves.

This package contains the development headers for the library found
in %lname.

%prep
%setup -q

%build
%configure --docdir=%_docdir/%name --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm -f "%buildroot/%_libdir"/*.la

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%_libdir/libFS.so.6*

%files devel
%defattr(-,root,root)
%_includedir/X11/*
%_libdir/libFS.so
%_libdir/pkgconfig/libfs.pc
%_docdir/%name

%changelog
* Sat Aug 27 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.9
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Import reallocarray() from libX11 (originally from OpenBSD)
  * Convert code to use FSmallocarray() & FSreallocarray()
* Mon Mar 11 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.0.8
  * autogen: add default patch prefix
  * autogen.sh: use quoted string variables
  * autogen.sh: use exec instead of waiting for configure to finish
  * Fix sign comparison warning in loop index in FSListFontsWithXInfo
  * Fix sign comparison warning in loop index in FSListCatalogues
  * Fix sign comparison warning in loop indexes in FSQueryXBitmaps{8,16}
  * Fix sign comparison warning in loop indexes in FSQueryXExtents{8,16}
  * Fix sign comparison warning in loop index in FSQueryXInfo
  * Don't try to send strings larger than protocol allows in requests
  * Update configure.ac bug URL for gitlab migration
  * Update README for gitlab migration
* Mon May  4 2015 sndirsch@suse.com
- Update to version 1.0.7
  * Constify pattern argument to FSListCatalogues
  * Constify some more strings in API arguments
  * Fix some sign/size conversion warnings from clang
  * Fix typos & wording issues in source comments
  * Remove unneeded checks for #ifndef X_NOT_POSIX
  * Use 'imdent' to realign cpp indentation levels in FSlibos.h
* Wed May  7 2014 sndirsch@suse.com
- Update to version 1.0.6
  * This minor maintenance release includes fixes for libxtrans 1.3
    compatibility, removal of dead code, and cleanups of issues
    found by static analyzers.
- supersedes U_fix_build_with_xtrans_1.3.patch
* Sun Nov  3 2013 tobias.johannes.klausmann@mni.thm.de
- Added U_fix_build_with_xtrans_1.3.patch
* Wed May 29 2013 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.0.5:
  This minor bugfix release includes the fix for the security issue recently
  reported as CVE-2013-1996, as well as a number of other cleanups of the
  memory allocation & error handling code noticed while working on that.
- Packaging changes:
  + Remove upstreamed patch: U_prototype_error.patch
    Included in this release
* Sun Feb 17 2013 jengelh@inai.de
- Use more robust make install call
* Fri Jul 13 2012 tobias.johannes.klausmann@mni.thm.de
- Added U_prototype_error.patch
  + Upstream fix for a prototype
* Wed Apr 11 2012 vuntz@opensuse.org
- Update to version 1.0.4:
  + Fixs a pile of issues found by static analysis & compiler
    warnings
  + Cleanup the library's exported symbol list
  + Build configuration improvements
* Tue Feb  7 2012 jengelh@medozas.de
- Split xorg-x11-libs into separate packages
